#include "stdafx.h"
#include "Texture.h"
#include <fstream.h>
#include "GL/glu.h"

//----------------------------------------
// Usefull debugger thingy.
void DebugOut(const char *szFormat, ...);
//----------------------------------------

// Change your App Name.
char szAppName[] = "Swirly Plasma";

// Timer info.  Very useful for keeping animated stuff in sync on different computers.
extern float fTime, fDeltaTime;
float dTime = 0;   //  Just a little thing to fake constant framerate.

// Current window dimensions.
extern GLsizei g_w, g_h;

int frams = 1;

// Pixel Buffers...
unsigned char *pPixelData = new unsigned char[512*384*3]; 
unsigned char *pPixelData2 = new unsigned char[512*384*3]; 
ofstream file;

GLUquadricObj *Inner;

CTexture gTexExample;

bool Init()	// Called right after the window is created, and OpenGL is initialized.
{
	glViewport (0, 0, (GLsizei) g_w, (GLsizei) g_h); 
	glMatrixMode (GL_PROJECTION);
	glLoadIdentity ();
	gluPerspective(135.0, 4.f/3.f, 0.001, 100.0);
	glMatrixMode(GL_MODELVIEW);
	glLoadIdentity();
	glClearColor(0.0,0.0,0.0,0.0);

	Inner = gluNewQuadric();
	gluQuadricNormals(Inner, GLU_SMOOTH);			// Create Smooth Normals (NEW)
	gluQuadricTexture(Inner, GL_TRUE);			// Create Texture Coords (NEW)


	gTexExample.LoadJPG( "background.jpg" );
	gTexExample.Use(); // Tells OpenGL to use this texture.
	glEnable( GL_TEXTURE_2D );
	glBlendFunc(GL_SRC_ALPHA, GL_ONE);
	glEnable(GL_BLEND);

	return true;
}

bool SaveSnap(int num, int quality)
{
	char fname[32];
	unsigned char *buff;
	sprintf(fname, "render\\Anm%04d.jpg",num);

	file.open(fname, ios::binary);

	int nbytes = 512 * 384 * 3;

	// Copy from OpenGL 
	// Don't forget to make OpenGL rendering context 
	// current (wglMakeCurrent)
	glReadPixels(0, 0, 512, 384, GL_RGB, GL_UNSIGNED_BYTE, pPixelData);

	// Flip the image because of GL's up = positve-y
	for (int j=0; j < 384; j ++)    // line counter
	{
		for (int i=0; i < 512;i++)  // column counter
		{
			pPixelData2[(j*512+i)*3] = pPixelData[((383-j)*512+i)*3];
			pPixelData2[(j*512+i)*3+1] = pPixelData[((383-j)*512+i)*3+1];
			pPixelData2[(j*512+i)*3+2] = pPixelData[((383-j)*512+i)*3+2];
		}
	}

	// Compressing in jpeg
	int len; // the length of the buffer after compression
	buff = (unsigned char*)Jpeg::Compress(pPixelData2, 512, 384, 3, len, quality);

	// Writing file and that's it
	file.write(buff,len); 
	file.close();

	delete buff;

	return TRUE;
}

void Shutdown() // Called right after the window is destroyed.
{
	// Cleaning memory
	delete [] pPixelData; 
	delete [] pPixelData2; 
}


void TheThing(int nr)
{
	glPushMatrix();

	//  Just a quick addition to phase in from whiteness...
	if (dTime <= 1.0)
	{
		glDisable( GL_TEXTURE_2D );
		glBegin(GL_QUADS);
			glColor4f(1.0, 1.0, 1.0, (1.0f - dTime));
			glVertex3f(-4.0, -3.0, -1.0);
			glVertex3f(4.0, -3.0, -1.0);
			glVertex3f(4.0, 3.0, -1.0);
			glVertex3f(-4.0, 3.0, -1.0);
		glEnd();
		glEnable( GL_TEXTURE_2D );
	}

	glTranslatef(0, 0, -1);
    glRotatef(nr/1.3f,1.0,0.0,0.0);
    glRotatef(nr/2.f,0,1.0,0.0);

	if (dTime <= 1.0)
		glColor4f(1.0f,1.0f,1.0f,dTime);
	else
		glColor4f(1.0f,1.0f,1.0f,1.0);

	gluSphere(Inner,1.3,32,32);
	glPopMatrix();
}

void Render()
{
	glClear( GL_COLOR_BUFFER_BIT );

	dTime += 1 / 29.97f;
	TheThing(frams);
//	SaveSnap(frams, 95);
	++frams;
}
